@@ -7,9 +7,10 @@ from django.http import HttpResponseRedirect
 from django.urls import reverse
 from django.utils.safestring import mark_safe
 
+from .admin_utils import remove_from_fieldsets
 from .filters import SearchInFilter
 from .forms import EnhancedBaseInlineFormSet
-from .utils import ifilter, remove_from_fieldsets
+from .utils import ifilter
 
 
 class EnhancedAdminInlineMixin(InlineModelAdmin):
